@@ -6,9 +6,9 @@ use serde::{Deserialize, Serialize};
 #[derive(Serialize, Deserialize, Debug)]
 #[serde(untagged)]
 pub enum Card {
-    Basic(BasicCardContent),
+    Basic(BasicCardContent), // 144 bytes
     Commerce(CommerceCardContent),
-    Item(ItemCardContent),
+    Item(ItemCardContent), // 360 bytes: Too big?
 }
 
 /***** BasicCard *****/
@@ -35,6 +35,12 @@ pub struct BasicCard {
     pub content: BasicCardContent,
 }
 
+impl Default for BasicCard {
+    fn default() -> Self {
+        Self::new()
+    }
+}
+
 impl BasicCard {
     pub fn new() -> Self {
         BasicCard {
@@ -142,6 +148,12 @@ pub struct CommerceCard {
     pub content: CommerceCardContent,
 }
 
+impl Default for CommerceCard {
+    fn default() -> Self {
+        Self::new()
+    }
+}
+
 impl CommerceCard {
     /// CommerceCard를 초기화 합니다.
     #[inline]
@@ -266,6 +278,12 @@ pub struct ItemCard {
     pub content: ItemCardContent,
 }
 
+impl Default for ItemCard {
+    fn default() -> Self {
+        Self::new()
+    }
+}
+
 impl ItemCard {
     /// ItemCard를 초기화 합니다.
     #[inline]
